@@ -23,14 +23,14 @@
 #include <apt-pkg/tagfile.h>
 
 #include <algorithm>
+#include <cctype>
+#include <cstddef>
 #include <cstring>
+#include <ctime>
 #include <fstream>
 #include <map>
 #include <string>
 #include <vector>
-#include <ctype.h>
-#include <stddef.h>
-#include <time.h>
 
 #include <apti18n.h>
 									/*}}}*/
@@ -614,7 +614,7 @@ bool pkgSourceList::AddVolatileFile(std::string const &File)
 									/*}}}*/
 void pkgSourceList::AddVolatileFiles(CommandLine &CmdL, std::vector<std::string> * const VolatileCmdL)/*{{{*/
 {
-   std::remove_if(CmdL.FileList + 1, CmdL.FileList + 1 + CmdL.FileSize(), [&](char const * const I) {
+   (void)std::remove_if(CmdL.FileList + 1, CmdL.FileList + 1 + CmdL.FileSize(), [&](char const * const I) {
       if (I != nullptr && (I[0] == '/' || (I[0] == '.' && (I[1] == '\0' || (I[1] == '.' && (I[2] == '\0' || I[2] == '/')) || I[1] == '/'))))
       {
 	 if (AddVolatileFile(I, VolatileCmdL))
